@@ -25,6 +25,14 @@ class CreateUserTests(TestCase):
         user = create_user(self.email, self.password)
         self.assertEquals(user.email, self.email)
 
+    def test_can_create_user_with_explicit_id(self):
+        """Regression test for
+        https://github.com/dabapps/django-email-as-username/issues/52
+
+        """
+        User.objects.create(email=self.email, id=1)
+
+
 
 class ExistingUserTests(TestCase):
     """
